==> dde-calendar_5.8.29.orig.tar.xz: dde-calendar-5.8.29/translations/dde-calendar-service_ka.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ka">
<context>
    <name>JobRemindManager</name>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="94"/>
        <source>One day before start</source>
        <translation>დაწყებამდე 1 დღით ადრე</translation>
    </message>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="94"/>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="98"/>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="105"/>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="109"/>
        <source>Close</source>
        <comment>button</comment>
        <translation>დახურვა</translation>
    </message>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="98"/>
        <source>Remind me tomorrow</source>
        <translation>შემახსენე ხვალ</translation>
    </message>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="105"/>
        <source>Remind me later</source>
        <translation>შემახსენე მოგვიანებით</translation>
    </message>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="116"/>
        <source>Schedule Reminder</source>
        <translation>შეხსენების დაგეგმვა</translation>
    </message>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="236"/>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="245"/>
        <source>%1 to %2</source>
        <translation>%1 დან %2</translation>
    </message>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="317"/>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="328"/>
        <source>Today</source>
        <translation>დღეს</translation>
    </message>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="320"/>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="331"/>
        <source>Tomorrow</source>
        <translation>ხვალ</translation>
    </message>
</context>
</TS>

==> dde-calendar_5.9.5.orig.tar.xz: dde-calendar-5.9.5/translations/dde-calendar-service_ka.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ka">
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>სამსახური</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>ცხოვრება</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>სხვა</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>დახურვა</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>დაწყებამდე 1 დღით ადრე</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>შემახსენე ხვალ</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>შემახსენე მოგვიანებით</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>1 hour later</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>4 hours later</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>ხვალ</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>შეხსენების დაგეგმვა</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>%1 დან %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>დღეს</translation>
    </message>
</context>
<context>
    <name>JobRemindManager</name>
    <message>
        <source>One day before start</source>
        <translation type="vanished">დაწყებამდე 1 დღით ადრე</translation>
    </message>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation type="vanished">დახურვა</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation type="vanished">შემახსენე ხვალ</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation type="vanished">შემახსენე მოგვიანებით</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation type="vanished">შეხსენების დაგეგმვა</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation type="vanished">%1 დან %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation type="vanished">დღეს</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation type="vanished">ხვალ</translation>
    </message>
</context>
</TS>
